@@ -1,8 +1,9 @@
 import unittest
 
-from insider.config import Port
 from convertible import to_json
 
+from syncloud.insider.config import Port
+
 class TestPortMapping(unittest.TestCase):
 
     def test_port_mapping(self):
